@@ -18,6 +18,7 @@ class Packet:
         self.meta = {}
         self.end_of_stream = False
         self.end_of_doc = False
+        self.format = FORMAT.any
 
     def consume(self):
         data = self.data
@@ -44,4 +45,4 @@ class Enum(object):
 
 # The data types allowed to pass in Packets, "any" can be used as wildcard
 FORMAT = Enum('xml_line_stream', 'etree_doc', 'etree_element_stream', 'etree_feature_array', 'xml_doc_as_string',
-              'string', 'any')
+              'string', 'record', 'struct', 'any')
